# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.open_ai_think_provider_model import OpenAiThinkProviderModel


class OpenAiThinkProviderParams(typing_extensions.TypedDict):
    type: typing.Literal["open_ai"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the OpenAI chat completions API
    """

    model: OpenAiThinkProviderModel
    """
    OpenAI model to use
    """

    temperature: typing_extensions.NotRequired[float]
    """
    OpenAI temperature (0-2)
    """



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ....core.api_error import ApiError
from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.http_response import AsyncHttpResponse, HttpResponse
from ....core.pydantic_utilities import parse_obj_as
from ....core.request_options import RequestOptions
from ....errors.bad_request_error import BadRequestError
from ....types.grant_v1response import GrantV1Response

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTokensClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def grant(
        self, *, ttl_seconds: typing.Optional[float] = OMIT, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GrantV1Response]:
        """
        Generates a temporary JSON Web Token (JWT) with a 30-second (by default) TTL and usage::write permission for core voice APIs, requiring an API key with Member or higher authorization. Tokens created with this endpoint will not work with the Manage APIs.

        Parameters
        ----------
        ttl_seconds : typing.Optional[float]
            Time to live in seconds for the token. Defaults to 30 seconds.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GrantV1Response]
            Grant response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/auth/grant",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "ttl_seconds": ttl_seconds,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GrantV1Response,
                    parse_obj_as(
                        type_=GrantV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTokensClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def grant(
        self, *, ttl_seconds: typing.Optional[float] = OMIT, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GrantV1Response]:
        """
        Generates a temporary JSON Web Token (JWT) with a 30-second (by default) TTL and usage::write permission for core voice APIs, requiring an API key with Member or higher authorization. Tokens created with this endpoint will not work with the Manage APIs.

        Parameters
        ----------
        ttl_seconds : typing.Optional[float]
            Time to live in seconds for the token. Defaults to 30 seconds.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GrantV1Response]
            Grant response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/auth/grant",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "ttl_seconds": ttl_seconds,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GrantV1Response,
                    parse_obj_as(
                        type_=GrantV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from .read_v1request_text import ReadV1RequestTextParams
from .read_v1request_url import ReadV1RequestUrlParams

ReadV1RequestParams = typing.Union[ReadV1RequestUrlParams, ReadV1RequestTextParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .speak_settings_v1endpoint import SpeakSettingsV1Endpoint
from .speak_settings_v1provider import SpeakSettingsV1Provider


class SpeakSettingsV1(UniversalBaseModel):
    provider: SpeakSettingsV1Provider
    endpoint: typing.Optional[SpeakSettingsV1Endpoint] = pydantic.Field(default=None)
    """
    Optional if provider is Deepgram. Required for non-Deepgram TTS providers.
    When present, must include url field and headers object. Valid schemes are https and wss with wss only supported for Eleven Labs.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .listen_v1close_stream import ListenV1CloseStreamParams
    from .listen_v1finalize import ListenV1FinalizeParams
    from .listen_v1keep_alive import ListenV1KeepAliveParams
    from .listen_v1metadata import ListenV1MetadataParams
    from .listen_v1results import ListenV1ResultsParams
    from .listen_v1results_channel import ListenV1ResultsChannelParams
    from .listen_v1results_channel_alternatives_item import ListenV1ResultsChannelAlternativesItemParams
    from .listen_v1results_channel_alternatives_item_words_item import (
        ListenV1ResultsChannelAlternativesItemWordsItemParams,
    )
    from .listen_v1results_entities_item import ListenV1ResultsEntitiesItemParams
    from .listen_v1results_metadata import ListenV1ResultsMetadataParams
    from .listen_v1results_metadata_model_info import ListenV1ResultsMetadataModelInfoParams
    from .listen_v1speech_started import ListenV1SpeechStartedParams
    from .listen_v1utterance_end import ListenV1UtteranceEndParams
_dynamic_imports: typing.Dict[str, str] = {
    "ListenV1CloseStreamParams": ".listen_v1close_stream",
    "ListenV1FinalizeParams": ".listen_v1finalize",
    "ListenV1KeepAliveParams": ".listen_v1keep_alive",
    "ListenV1MetadataParams": ".listen_v1metadata",
    "ListenV1ResultsChannelAlternativesItemParams": ".listen_v1results_channel_alternatives_item",
    "ListenV1ResultsChannelAlternativesItemWordsItemParams": ".listen_v1results_channel_alternatives_item_words_item",
    "ListenV1ResultsChannelParams": ".listen_v1results_channel",
    "ListenV1ResultsEntitiesItemParams": ".listen_v1results_entities_item",
    "ListenV1ResultsMetadataModelInfoParams": ".listen_v1results_metadata_model_info",
    "ListenV1ResultsMetadataParams": ".listen_v1results_metadata",
    "ListenV1ResultsParams": ".listen_v1results",
    "ListenV1SpeechStartedParams": ".listen_v1speech_started",
    "ListenV1UtteranceEndParams": ".listen_v1utterance_end",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ListenV1CloseStreamParams",
    "ListenV1FinalizeParams",
    "ListenV1KeepAliveParams",
    "ListenV1MetadataParams",
    "ListenV1ResultsChannelAlternativesItemParams",
    "ListenV1ResultsChannelAlternativesItemWordsItemParams",
    "ListenV1ResultsChannelParams",
    "ListenV1ResultsEntitiesItemParams",
    "ListenV1ResultsMetadataModelInfoParams",
    "ListenV1ResultsMetadataParams",
    "ListenV1ResultsParams",
    "ListenV1SpeechStartedParams",
    "ListenV1UtteranceEndParams",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .get_model_v1response_batch import GetModelV1ResponseBatch
from .get_model_v1response_metadata import GetModelV1ResponseMetadata

GetModelV1Response = typing.Union[GetModelV1ResponseBatch, GetModelV1ResponseMetadata]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GetModelV1ResponseBatch(UniversalBaseModel):
    name: typing.Optional[str] = None
    canonical_name: typing.Optional[str] = None
    architecture: typing.Optional[str] = None
    languages: typing.Optional[typing.List[str]] = None
    version: typing.Optional[str] = None
    uuid_: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="uuid"), pydantic.Field(alias="uuid")
    ] = None
    batch: typing.Optional[bool] = None
    streaming: typing.Optional[bool] = None
    formatted_output: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1conversation_text_role import AgentV1ConversationTextRole


class AgentV1ConversationText(UniversalBaseModel):
    type: typing.Literal["ConversationText"] = pydantic.Field(default="ConversationText")
    """
    Message type identifier for conversation text
    """

    role: AgentV1ConversationTextRole = pydantic.Field()
    """
    Identifies who spoke the statement
    """

    content: str = pydantic.Field()
    """
    The actual statement that was spoken
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1results_channel import ListenV1ResultsChannelParams
from .listen_v1results_entities_item import ListenV1ResultsEntitiesItemParams
from .listen_v1results_metadata import ListenV1ResultsMetadataParams


class ListenV1ResultsParams(typing_extensions.TypedDict):
    type: typing.Literal["Results"]
    """
    Message type identifier
    """

    channel_index: typing.Sequence[float]
    """
    The index of the channel
    """

    duration: float
    """
    The duration of the transcription
    """

    start: float
    """
    The start time of the transcription
    """

    is_final: typing_extensions.NotRequired[bool]
    """
    Whether the transcription is final
    """

    speech_final: typing_extensions.NotRequired[bool]
    """
    Whether the transcription is speech final
    """

    channel: ListenV1ResultsChannelParams
    metadata: ListenV1ResultsMetadataParams
    from_finalize: typing_extensions.NotRequired[bool]
    """
    Whether the transcription is from a finalize message
    """

    entities: typing_extensions.NotRequired[typing.Sequence[ListenV1ResultsEntitiesItemParams]]
    """
    Extracted entities from the audio when detect_entities is enabled. Only present in is_final messages. Returns an empty array if no entities are detected
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV2FatalErrorParams(typing_extensions.TypedDict):
    type: typing.Literal["Error"]
    """
    Message type identifier
    """

    sequence_id: float
    """
    Starts at `0` and increments for each message the server sends
    to the client.  This includes messages of other types, like
    `Connected` messages.
    """

    code: str
    """
    A string code describing the error, e.g. `INTERNAL_SERVER_ERROR`
    """

    description: str
    """
    Prose description of the error
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_utterances_item_words_item import ListenV1ResponseResultsUtterancesItemWordsItemParams


class ListenV1ResponseResultsUtterancesItemParams(typing_extensions.TypedDict):
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    confidence: typing_extensions.NotRequired[float]
    channel: typing_extensions.NotRequired[float]
    transcript: typing_extensions.NotRequired[str]
    words: typing_extensions.NotRequired[typing.Sequence[ListenV1ResponseResultsUtterancesItemWordsItemParams]]
    speaker: typing_extensions.NotRequired[float]
    id: typing_extensions.NotRequired[str]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_models_v1response_stt_models import ListModelsV1ResponseSttModelsParams
from .list_models_v1response_tts_models import ListModelsV1ResponseTtsModelsParams


class ListModelsV1ResponseParams(typing_extensions.TypedDict):
    stt: typing_extensions.NotRequired[typing.Sequence[ListModelsV1ResponseSttModelsParams]]
    tts: typing_extensions.NotRequired[typing.Sequence[ListModelsV1ResponseTtsModelsParams]]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class UsageFieldsV1ResponseModelsItemParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[str]
    """
    Name of the model.
    """

    language: typing_extensions.NotRequired[str]
    """
    The language supported by the model (IETF language tag).
    """

    version: typing_extensions.NotRequired[str]
    """
    Version identifier of the model, typically with a date and a revision number.
    """

    model_id: typing_extensions.NotRequired[str]
    """
    Unique identifier for the model.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetProjectBalanceV1Response(UniversalBaseModel):
    balance_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the balance
    """

    amount: typing.Optional[float] = pydantic.Field(default=None)
    """
    The amount of the balance
    """

    units: typing.Optional[str] = pydantic.Field(default=None)
    """
    The units of the balance, such as "USD"
    """

    purchase_order_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Description or reference of the purchase
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.request_options import RequestOptions
from .raw_client import AsyncRawAudioClient, RawAudioClient
from .types.audio_generate_request_callback_method import AudioGenerateRequestCallbackMethod
from .types.audio_generate_request_container import AudioGenerateRequestContainer
from .types.audio_generate_request_encoding import AudioGenerateRequestEncoding
from .types.audio_generate_request_model import AudioGenerateRequestModel

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AudioClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAudioClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAudioClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAudioClient
        """
        return self._raw_client

    def generate(
        self,
        *,
        text: str,
        callback: typing.Optional[str] = None,
        callback_method: typing.Optional[AudioGenerateRequestCallbackMethod] = None,
        mip_opt_out: typing.Optional[bool] = None,
        tag: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        bit_rate: typing.Optional[float] = None,
        container: typing.Optional[AudioGenerateRequestContainer] = None,
        encoding: typing.Optional[AudioGenerateRequestEncoding] = None,
        model: typing.Optional[AudioGenerateRequestModel] = None,
        sample_rate: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Convert text into natural-sounding speech using Deepgram's TTS REST API

        Parameters
        ----------
        text : str
            The text content to be converted to speech

        callback : typing.Optional[str]
            URL to which we'll make the callback request

        callback_method : typing.Optional[AudioGenerateRequestCallbackMethod]
            HTTP method by which the callback request will be made

        mip_opt_out : typing.Optional[bool]
            Opts out requests from the Deepgram Model Improvement Program. Refer to our Docs for pricing impacts before setting this to true. https://dpgr.am/deepgram-mip

        tag : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Label your requests for the purpose of identification during usage reporting

        bit_rate : typing.Optional[float]
            The bitrate of the audio in bits per second. Choose from predefined ranges or specific values based on the encoding type.

        container : typing.Optional[AudioGenerateRequestContainer]
            Container specifies the file format wrapper for the output audio. The available options depend on the encoding type.

        encoding : typing.Optional[AudioGenerateRequestEncoding]
            Encoding allows you to specify the expected encoding of your audio output

        model : typing.Optional[AudioGenerateRequestModel]
            AI model used to process submitted text

        sample_rate : typing.Optional[float]
            Sample Rate specifies the sample rate for the output audio. Based on the encoding, different sample rates are supported. For some encodings, the sample rate is not configurable

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.Iterator[bytes]
            Successful text-to-speech transformation

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.speak.v1.audio.generate(
            text="text",
        )
        """
        with self._raw_client.generate(
            text=text,
            callback=callback,
            callback_method=callback_method,
            mip_opt_out=mip_opt_out,
            tag=tag,
            bit_rate=bit_rate,
            container=container,
            encoding=encoding,
            model=model,
            sample_rate=sample_rate,
            request_options=request_options,
        ) as r:
            yield from r.data


class AsyncAudioClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAudioClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAudioClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAudioClient
        """
        return self._raw_client

    async def generate(
        self,
        *,
        text: str,
        callback: typing.Optional[str] = None,
        callback_method: typing.Optional[AudioGenerateRequestCallbackMethod] = None,
        mip_opt_out: typing.Optional[bool] = None,
        tag: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        bit_rate: typing.Optional[float] = None,
        container: typing.Optional[AudioGenerateRequestContainer] = None,
        encoding: typing.Optional[AudioGenerateRequestEncoding] = None,
        model: typing.Optional[AudioGenerateRequestModel] = None,
        sample_rate: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Convert text into natural-sounding speech using Deepgram's TTS REST API

        Parameters
        ----------
        text : str
            The text content to be converted to speech

        callback : typing.Optional[str]
            URL to which we'll make the callback request

        callback_method : typing.Optional[AudioGenerateRequestCallbackMethod]
            HTTP method by which the callback request will be made

        mip_opt_out : typing.Optional[bool]
            Opts out requests from the Deepgram Model Improvement Program. Refer to our Docs for pricing impacts before setting this to true. https://dpgr.am/deepgram-mip

        tag : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            Label your requests for the purpose of identification during usage reporting

        bit_rate : typing.Optional[float]
            The bitrate of the audio in bits per second. Choose from predefined ranges or specific values based on the encoding type.

        container : typing.Optional[AudioGenerateRequestContainer]
            Container specifies the file format wrapper for the output audio. The available options depend on the encoding type.

        encoding : typing.Optional[AudioGenerateRequestEncoding]
            Encoding allows you to specify the expected encoding of your audio output

        model : typing.Optional[AudioGenerateRequestModel]
            AI model used to process submitted text

        sample_rate : typing.Optional[float]
            Sample Rate specifies the sample rate for the output audio. Based on the encoding, different sample rates are supported. For some encodings, the sample rate is not configurable

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Returns
        -------
        typing.AsyncIterator[bytes]
            Successful text-to-speech transformation

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.speak.v1.audio.generate(
                text="text",
            )


        asyncio.run(main())
        """
        async with self._raw_client.generate(
            text=text,
            callback=callback,
            callback_method=callback_method,
            mip_opt_out=mip_opt_out,
            tag=tag,
            bit_rate=bit_rate,
            container=container,
            encoding=encoding,
            model=model,
            sample_rate=sample_rate,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class CreateKeyV1ResponseParams(typing_extensions.TypedDict):
    """
    API key created
    """

    api_key_id: typing_extensions.NotRequired[str]
    """
    The unique identifier of the API key
    """

    key: typing_extensions.NotRequired[str]
    """
    The API key
    """

    comment: typing_extensions.NotRequired[str]
    """
    A comment for the API key
    """

    scopes: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The scopes for the API key
    """

    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The tags for the API key
    """

    expiration_date: typing_extensions.NotRequired[dt.datetime]
    """
    The expiration date of the API key
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV1MetadataParams(typing_extensions.TypedDict):
    type: typing.Literal["Metadata"]
    """
    Message type identifier
    """

    transaction_key: str
    """
    The transaction key
    """

    request_id: str
    """
    The request ID
    """

    sha256: str
    """
    The sha256
    """

    created: str
    """
    The created
    """

    duration: float
    """
    The duration
    """

    channels: float
    """
    The channels
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ListenV2ConnectedParams(typing_extensions.TypedDict):
    type: typing.Literal["Connected"]
    """
    Message type identifier
    """

    request_id: str
    """
    The unique identifier of the request
    """

    sequence_id: float
    """
    Starts at `0` and increments for each message the server sends
    to the client.  This includes messages of other types, like
    `TurnInfo` messages.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1SettingsAgentListenProviderV1Params(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    """
    Provider type for speech-to-text
    """

    model: typing_extensions.NotRequired[str]
    """
    Model to use for speech to text using the V1 API (e.g. Nova-3, Nova-2)
    """

    language: typing_extensions.NotRequired[str]
    """
    Language code to use for speech-to-text. Can be a BCP-47 language tag (e.g. `en`), or `multi` for code-switching transcription
    """

    keyterms: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """

    smart_format: typing_extensions.NotRequired[bool]
    """
    Applies smart formatting to improve transcript readability
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .shared_topics_results import SharedTopicsResultsParams


class SharedTopicsParams(typing_extensions.TypedDict):
    """
    Output whenever `topics=true` is used
    """

    results: typing_extensions.NotRequired[SharedTopicsResultsParams]



# This file was auto-generated by Fern from our API Definition.

import typing

AgentThinkModelsV1ResponseModelsItemZeroId = typing.Union[
    typing.Literal[
        "gpt-5", "gpt-5-mini", "gpt-5-nano", "gpt-4.1", "gpt-4.1-mini", "gpt-4.1-nano", "gpt-4o", "gpt-4o-mini"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ListenV1ResultsChannelAlternativesItemWordsItem(UniversalBaseModel):
    word: str = pydantic.Field()
    """
    The word of the transcription
    """

    start: float = pydantic.Field()
    """
    The start time of the word
    """

    end: float = pydantic.Field()
    """
    The end time of the word
    """

    confidence: float = pydantic.Field()
    """
    The confidence of the word
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    The language of the word
    """

    punctuated_word: typing.Optional[str] = pydantic.Field(default=None)
    """
    The punctuated word of the word
    """

    speaker: typing.Optional[float] = pydantic.Field(default=None)
    """
    The speaker of the word
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ....requests.think_settings_v1 import ThinkSettingsV1Params

AgentV1SettingsAgentThinkParams = typing.Union[ThinkSettingsV1Params, typing.Sequence[ThinkSettingsV1Params]]



# This file was auto-generated by Fern from our API Definition.

import typing

ListenV1Redact = typing.Optional[
    typing.Union[
        typing.Literal["true", "false", "pci", "numbers", "aggressive_numbers", "ssn"],
        str,
        typing.Sequence[str],
    ]
]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1InjectAgentMessageParams(typing_extensions.TypedDict):
    type: typing.Literal["InjectAgentMessage"]
    """
    Message type identifier for injecting an agent message
    """

    message: str
    """
    The statement that the agent should say
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_entities_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_paragraphs import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams,
)
from .listen_v1response_results_channels_item_alternatives_item_summaries_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_topics_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams,
)
from .listen_v1response_results_channels_item_alternatives_item_words_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParams(typing_extensions.TypedDict):
    transcript: typing_extensions.NotRequired[str]
    confidence: typing_extensions.NotRequired[float]
    words: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemWordsItemParams]
    ]
    paragraphs: typing_extensions.NotRequired[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams]
    entities: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemEntitiesItemParams]
    ]
    summaries: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemSummariesItemParams]
    ]
    topics: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemTopicsItemParams]
    ]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_project_distribution_credentials_v1response_distribution_credentials import (
    GetProjectDistributionCredentialsV1ResponseDistributionCredentials,
)
from .get_project_distribution_credentials_v1response_member import GetProjectDistributionCredentialsV1ResponseMember


class GetProjectDistributionCredentialsV1Response(UniversalBaseModel):
    member: GetProjectDistributionCredentialsV1ResponseMember
    distribution_credentials: GetProjectDistributionCredentialsV1ResponseDistributionCredentials

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import os
import typing

import httpx
from .core.api_error import ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import DeepgramClientEnvironment

if typing.TYPE_CHECKING:
    from .agent.client import AgentClient, AsyncAgentClient
    from .auth.client import AsyncAuthClient, AuthClient
    from .listen.client import AsyncListenClient, ListenClient
    from .manage.client import AsyncManageClient, ManageClient
    from .read.client import AsyncReadClient, ReadClient
    from .self_hosted.client import AsyncSelfHostedClient, SelfHostedClient
    from .speak.client import AsyncSpeakClient, SpeakClient


class BaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    environment : DeepgramClientEnvironment
        The environment to use for requests from the client. from .environment import DeepgramClientEnvironment



        Defaults to DeepgramClientEnvironment.PRODUCTION



    api_key : typing.Optional[str]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from deepgram import DeepgramClient

    client = DeepgramClient(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        environment: DeepgramClientEnvironment = DeepgramClientEnvironment.PRODUCTION,
        api_key: typing.Optional[str] = os.getenv("DEEPGRAM_API_KEY"),
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(
                body="The client must be instantiated be either passing in api_key or setting DEEPGRAM_API_KEY"
            )
        self._client_wrapper = SyncClientWrapper(
            environment=environment,
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._agent: typing.Optional[AgentClient] = None
        self._auth: typing.Optional[AuthClient] = None
        self._listen: typing.Optional[ListenClient] = None
        self._manage: typing.Optional[ManageClient] = None
        self._read: typing.Optional[ReadClient] = None
        self._self_hosted: typing.Optional[SelfHostedClient] = None
        self._speak: typing.Optional[SpeakClient] = None

    @property
    def agent(self):
        if self._agent is None:
            from .agent.client import AgentClient  # noqa: E402

            self._agent = AgentClient(client_wrapper=self._client_wrapper)
        return self._agent

    @property
    def auth(self):
        if self._auth is None:
            from .auth.client import AuthClient  # noqa: E402

            self._auth = AuthClient(client_wrapper=self._client_wrapper)
        return self._auth

    @property
    def listen(self):
        if self._listen is None:
            from .listen.client import ListenClient  # noqa: E402

            self._listen = ListenClient(client_wrapper=self._client_wrapper)
        return self._listen

    @property
    def manage(self):
        if self._manage is None:
            from .manage.client import ManageClient  # noqa: E402

            self._manage = ManageClient(client_wrapper=self._client_wrapper)
        return self._manage

    @property
    def read(self):
        if self._read is None:
            from .read.client import ReadClient  # noqa: E402

            self._read = ReadClient(client_wrapper=self._client_wrapper)
        return self._read

    @property
    def self_hosted(self):
        if self._self_hosted is None:
            from .self_hosted.client import SelfHostedClient  # noqa: E402

            self._self_hosted = SelfHostedClient(client_wrapper=self._client_wrapper)
        return self._self_hosted

    @property
    def speak(self):
        if self._speak is None:
            from .speak.client import SpeakClient  # noqa: E402

            self._speak = SpeakClient(client_wrapper=self._client_wrapper)
        return self._speak


class AsyncBaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    environment : DeepgramClientEnvironment
        The environment to use for requests from the client. from .environment import DeepgramClientEnvironment



        Defaults to DeepgramClientEnvironment.PRODUCTION



    api_key : typing.Optional[str]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from deepgram import AsyncDeepgramClient

    client = AsyncDeepgramClient(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        environment: DeepgramClientEnvironment = DeepgramClientEnvironment.PRODUCTION,
        api_key: typing.Optional[str] = os.getenv("DEEPGRAM_API_KEY"),
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(
                body="The client must be instantiated be either passing in api_key or setting DEEPGRAM_API_KEY"
            )
        self._client_wrapper = AsyncClientWrapper(
            environment=environment,
            api_key=api_key,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._agent: typing.Optional[AsyncAgentClient] = None
        self._auth: typing.Optional[AsyncAuthClient] = None
        self._listen: typing.Optional[AsyncListenClient] = None
        self._manage: typing.Optional[AsyncManageClient] = None
        self._read: typing.Optional[AsyncReadClient] = None
        self._self_hosted: typing.Optional[AsyncSelfHostedClient] = None
        self._speak: typing.Optional[AsyncSpeakClient] = None

    @property
    def agent(self):
        if self._agent is None:
            from .agent.client import AsyncAgentClient  # noqa: E402

            self._agent = AsyncAgentClient(client_wrapper=self._client_wrapper)
        return self._agent

    @property
    def auth(self):
        if self._auth is None:
            from .auth.client import AsyncAuthClient  # noqa: E402

            self._auth = AsyncAuthClient(client_wrapper=self._client_wrapper)
        return self._auth

    @property
    def listen(self):
        if self._listen is None:
            from .listen.client import AsyncListenClient  # noqa: E402

            self._listen = AsyncListenClient(client_wrapper=self._client_wrapper)
        return self._listen

    @property
    def manage(self):
        if self._manage is None:
            from .manage.client import AsyncManageClient  # noqa: E402

            self._manage = AsyncManageClient(client_wrapper=self._client_wrapper)
        return self._manage

    @property
    def read(self):
        if self._read is None:
            from .read.client import AsyncReadClient  # noqa: E402

            self._read = AsyncReadClient(client_wrapper=self._client_wrapper)
        return self._read

    @property
    def self_hosted(self):
        if self._self_hosted is None:
            from .self_hosted.client import AsyncSelfHostedClient  # noqa: E402

            self._self_hosted = AsyncSelfHostedClient(client_wrapper=self._client_wrapper)
        return self._self_hosted

    @property
    def speak(self):
        if self._speak is None:
            from .speak.client import AsyncSpeakClient  # noqa: E402

            self._speak = AsyncSpeakClient(client_wrapper=self._client_wrapper)
        return self._speak



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BillingBreakdownV1ResponseResultsItemGrouping(UniversalBaseModel):
    start: typing.Optional[str] = pydantic.Field(default=None)
    """
    Start date for this group
    """

    end: typing.Optional[str] = pydantic.Field(default=None)
    """
    End date for this group
    """

    accessor: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional accessor identifier, null unless grouped by accessor.
    """

    deployment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional deployment identifier, null unless grouped by deployment.
    """

    line_item: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional line item identifier, null unless grouped by line item.
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Optional list of tags, null unless grouped by tags.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from .....errors.bad_request_error import BadRequestError
from .....types.usage_v1response import UsageV1Response
from .types.usage_get_request_deployment import UsageGetRequestDeployment
from .types.usage_get_request_endpoint import UsageGetRequestEndpoint
from .types.usage_get_request_method import UsageGetRequestMethod


class RawUsageClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        accessor: typing.Optional[str] = None,
        alternatives: typing.Optional[bool] = None,
        callback_method: typing.Optional[bool] = None,
        callback: typing.Optional[bool] = None,
        channels: typing.Optional[bool] = None,
        custom_intent_mode: typing.Optional[bool] = None,
        custom_intent: typing.Optional[bool] = None,
        custom_topic_mode: typing.Optional[bool] = None,
        custom_topic: typing.Optional[bool] = None,
        deployment: typing.Optional[UsageGetRequestDeployment] = None,
        detect_entities: typing.Optional[bool] = None,
        detect_language: typing.Optional[bool] = None,
        diarize: typing.Optional[bool] = None,
        dictation: typing.Optional[bool] = None,
        encoding: typing.Optional[bool] = None,
        endpoint: typing.Optional[UsageGetRequestEndpoint] = None,
        extra: typing.Optional[bool] = None,
        filler_words: typing.Optional[bool] = None,
        intents: typing.Optional[bool] = None,
        keyterm: typing.Optional[bool] = None,
        keywords: typing.Optional[bool] = None,
        language: typing.Optional[bool] = None,
        measurements: typing.Optional[bool] = None,
        method: typing.Optional[UsageGetRequestMethod] = None,
        model: typing.Optional[str] = None,
        multichannel: typing.Optional[bool] = None,
        numerals: typing.Optional[bool] = None,
        paragraphs: typing.Optional[bool] = None,
        profanity_filter: typing.Optional[bool] = None,
        punctuate: typing.Optional[bool] = None,
        redact: typing.Optional[bool] = None,
        replace: typing.Optional[bool] = None,
        sample_rate: typing.Optional[bool] = None,
        search: typing.Optional[bool] = None,
        sentiment: typing.Optional[bool] = None,
        smart_format: typing.Optional[bool] = None,
        summarize: typing.Optional[bool] = None,
        tag: typing.Optional[str] = None,
        topics: typing.Optional[bool] = None,
        utt_split: typing.Optional[bool] = None,
        utterances: typing.Optional[bool] = None,
        version: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UsageV1Response]:
        """
        Retrieves the usage for a specific project. Use Get Project Usage Breakdown for a more comprehensive usage summary.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        alternatives : typing.Optional[bool]
            Filter for requests where alternatives were used

        callback_method : typing.Optional[bool]
            Filter for requests where callback method was used

        callback : typing.Optional[bool]
            Filter for requests where callback was used

        channels : typing.Optional[bool]
            Filter for requests where channels were used

        custom_intent_mode : typing.Optional[bool]
            Filter for requests where custom intent mode was used

        custom_intent : typing.Optional[bool]
            Filter for requests where custom intent was used

        custom_topic_mode : typing.Optional[bool]
            Filter for requests where custom topic mode was used

        custom_topic : typing.Optional[bool]
            Filter for requests where custom topic was used

        deployment : typing.Optional[UsageGetRequestDeployment]
            Filter for requests where a specific deployment was used

        detect_entities : typing.Optional[bool]
            Filter for requests where detect entities was used

        detect_language : typing.Optional[bool]
            Filter for requests where detect language was used

        diarize : typing.Optional[bool]
            Filter for requests where diarize was used

        dictation : typing.Optional[bool]
            Filter for requests where dictation was used

        encoding : typing.Optional[bool]
            Filter for requests where encoding was used

        endpoint : typing.Optional[UsageGetRequestEndpoint]
            Filter for requests where a specific endpoint was used

        extra : typing.Optional[bool]
            Filter for requests where extra was used

        filler_words : typing.Optional[bool]
            Filter for requests where filler words was used

        intents : typing.Optional[bool]
            Filter for requests where intents was used

        keyterm : typing.Optional[bool]
            Filter for requests where keyterm was used

        keywords : typing.Optional[bool]
            Filter for requests where keywords was used

        language : typing.Optional[bool]
            Filter for requests where language was used

        measurements : typing.Optional[bool]
            Filter for requests where measurements were used

        method : typing.Optional[UsageGetRequestMethod]
            Filter for requests where a specific method was used

        model : typing.Optional[str]
            Filter for requests where a specific model uuid was used

        multichannel : typing.Optional[bool]
            Filter for requests where multichannel was used

        numerals : typing.Optional[bool]
            Filter for requests where numerals were used

        paragraphs : typing.Optional[bool]
            Filter for requests where paragraphs were used

        profanity_filter : typing.Optional[bool]
            Filter for requests where profanity filter was used

        punctuate : typing.Optional[bool]
            Filter for requests where punctuate was used

        redact : typing.Optional[bool]
            Filter for requests where redact was used

        replace : typing.Optional[bool]
            Filter for requests where replace was used

        sample_rate : typing.Optional[bool]
            Filter for requests where sample rate was used

        search : typing.Optional[bool]
            Filter for requests where search was used

        sentiment : typing.Optional[bool]
            Filter for requests where sentiment was used

        smart_format : typing.Optional[bool]
            Filter for requests where smart format was used

        summarize : typing.Optional[bool]
            Filter for requests where summarize was used

        tag : typing.Optional[str]
            Filter for requests where a specific tag was used

        topics : typing.Optional[bool]
            Filter for requests where topics was used

        utt_split : typing.Optional[bool]
            Filter for requests where utt split was used

        utterances : typing.Optional[bool]
            Filter for requests where utterances was used

        version : typing.Optional[bool]
            Filter for requests where version was used

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UsageV1Response]
            A specific request for a specific project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/usage",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
                "accessor": accessor,
                "alternatives": alternatives,
                "callback_method": callback_method,
                "callback": callback,
                "channels": channels,
                "custom_intent_mode": custom_intent_mode,
                "custom_intent": custom_intent,
                "custom_topic_mode": custom_topic_mode,
                "custom_topic": custom_topic,
                "deployment": deployment,
                "detect_entities": detect_entities,
                "detect_language": detect_language,
                "diarize": diarize,
                "dictation": dictation,
                "encoding": encoding,
                "endpoint": endpoint,
                "extra": extra,
                "filler_words": filler_words,
                "intents": intents,
                "keyterm": keyterm,
                "keywords": keywords,
                "language": language,
                "measurements": measurements,
                "method": method,
                "model": model,
                "multichannel": multichannel,
                "numerals": numerals,
                "paragraphs": paragraphs,
                "profanity_filter": profanity_filter,
                "punctuate": punctuate,
                "redact": redact,
                "replace": replace,
                "sample_rate": sample_rate,
                "search": search,
                "sentiment": sentiment,
                "smart_format": smart_format,
                "summarize": summarize,
                "tag": tag,
                "topics": topics,
                "utt_split": utt_split,
                "utterances": utterances,
                "version": version,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UsageV1Response,
                    parse_obj_as(
                        type_=UsageV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawUsageClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        accessor: typing.Optional[str] = None,
        alternatives: typing.Optional[bool] = None,
        callback_method: typing.Optional[bool] = None,
        callback: typing.Optional[bool] = None,
        channels: typing.Optional[bool] = None,
        custom_intent_mode: typing.Optional[bool] = None,
        custom_intent: typing.Optional[bool] = None,
        custom_topic_mode: typing.Optional[bool] = None,
        custom_topic: typing.Optional[bool] = None,
        deployment: typing.Optional[UsageGetRequestDeployment] = None,
        detect_entities: typing.Optional[bool] = None,
        detect_language: typing.Optional[bool] = None,
        diarize: typing.Optional[bool] = None,
        dictation: typing.Optional[bool] = None,
        encoding: typing.Optional[bool] = None,
        endpoint: typing.Optional[UsageGetRequestEndpoint] = None,
        extra: typing.Optional[bool] = None,
        filler_words: typing.Optional[bool] = None,
        intents: typing.Optional[bool] = None,
        keyterm: typing.Optional[bool] = None,
        keywords: typing.Optional[bool] = None,
        language: typing.Optional[bool] = None,
        measurements: typing.Optional[bool] = None,
        method: typing.Optional[UsageGetRequestMethod] = None,
        model: typing.Optional[str] = None,
        multichannel: typing.Optional[bool] = None,
        numerals: typing.Optional[bool] = None,
        paragraphs: typing.Optional[bool] = None,
        profanity_filter: typing.Optional[bool] = None,
        punctuate: typing.Optional[bool] = None,
        redact: typing.Optional[bool] = None,
        replace: typing.Optional[bool] = None,
        sample_rate: typing.Optional[bool] = None,
        search: typing.Optional[bool] = None,
        sentiment: typing.Optional[bool] = None,
        smart_format: typing.Optional[bool] = None,
        summarize: typing.Optional[bool] = None,
        tag: typing.Optional[str] = None,
        topics: typing.Optional[bool] = None,
        utt_split: typing.Optional[bool] = None,
        utterances: typing.Optional[bool] = None,
        version: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UsageV1Response]:
        """
        Retrieves the usage for a specific project. Use Get Project Usage Breakdown for a more comprehensive usage summary.

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        accessor : typing.Optional[str]
            Filter for requests where a specific accessor was used

        alternatives : typing.Optional[bool]
            Filter for requests where alternatives were used

        callback_method : typing.Optional[bool]
            Filter for requests where callback method was used

        callback : typing.Optional[bool]
            Filter for requests where callback was used

        channels : typing.Optional[bool]
            Filter for requests where channels were used

        custom_intent_mode : typing.Optional[bool]
            Filter for requests where custom intent mode was used

        custom_intent : typing.Optional[bool]
            Filter for requests where custom intent was used

        custom_topic_mode : typing.Optional[bool]
            Filter for requests where custom topic mode was used

        custom_topic : typing.Optional[bool]
            Filter for requests where custom topic was used

        deployment : typing.Optional[UsageGetRequestDeployment]
            Filter for requests where a specific deployment was used

        detect_entities : typing.Optional[bool]
            Filter for requests where detect entities was used

        detect_language : typing.Optional[bool]
            Filter for requests where detect language was used

        diarize : typing.Optional[bool]
            Filter for requests where diarize was used

        dictation : typing.Optional[bool]
            Filter for requests where dictation was used

        encoding : typing.Optional[bool]
            Filter for requests where encoding was used

        endpoint : typing.Optional[UsageGetRequestEndpoint]
            Filter for requests where a specific endpoint was used

        extra : typing.Optional[bool]
            Filter for requests where extra was used

        filler_words : typing.Optional[bool]
            Filter for requests where filler words was used

        intents : typing.Optional[bool]
            Filter for requests where intents was used

        keyterm : typing.Optional[bool]
            Filter for requests where keyterm was used

        keywords : typing.Optional[bool]
            Filter for requests where keywords was used

        language : typing.Optional[bool]
            Filter for requests where language was used

        measurements : typing.Optional[bool]
            Filter for requests where measurements were used

        method : typing.Optional[UsageGetRequestMethod]
            Filter for requests where a specific method was used

        model : typing.Optional[str]
            Filter for requests where a specific model uuid was used

        multichannel : typing.Optional[bool]
            Filter for requests where multichannel was used

        numerals : typing.Optional[bool]
            Filter for requests where numerals were used

        paragraphs : typing.Optional[bool]
            Filter for requests where paragraphs were used

        profanity_filter : typing.Optional[bool]
            Filter for requests where profanity filter was used

        punctuate : typing.Optional[bool]
            Filter for requests where punctuate was used

        redact : typing.Optional[bool]
            Filter for requests where redact was used

        replace : typing.Optional[bool]
            Filter for requests where replace was used

        sample_rate : typing.Optional[bool]
            Filter for requests where sample rate was used

        search : typing.Optional[bool]
            Filter for requests where search was used

        sentiment : typing.Optional[bool]
            Filter for requests where sentiment was used

        smart_format : typing.Optional[bool]
            Filter for requests where smart format was used

        summarize : typing.Optional[bool]
            Filter for requests where summarize was used

        tag : typing.Optional[str]
            Filter for requests where a specific tag was used

        topics : typing.Optional[bool]
            Filter for requests where topics was used

        utt_split : typing.Optional[bool]
            Filter for requests where utt split was used

        utterances : typing.Optional[bool]
            Filter for requests where utterances was used

        version : typing.Optional[bool]
            Filter for requests where version was used

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UsageV1Response]
            A specific request for a specific project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/usage",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
                "accessor": accessor,
                "alternatives": alternatives,
                "callback_method": callback_method,
                "callback": callback,
                "channels": channels,
                "custom_intent_mode": custom_intent_mode,
                "custom_intent": custom_intent,
                "custom_topic_mode": custom_topic_mode,
                "custom_topic": custom_topic,
                "deployment": deployment,
                "detect_entities": detect_entities,
                "detect_language": detect_language,
                "diarize": diarize,
                "dictation": dictation,
                "encoding": encoding,
                "endpoint": endpoint,
                "extra": extra,
                "filler_words": filler_words,
                "intents": intents,
                "keyterm": keyterm,
                "keywords": keywords,
                "language": language,
                "measurements": measurements,
                "method": method,
                "model": model,
                "multichannel": multichannel,
                "numerals": numerals,
                "paragraphs": paragraphs,
                "profanity_filter": profanity_filter,
                "punctuate": punctuate,
                "redact": redact,
                "replace": replace,
                "sample_rate": sample_rate,
                "search": search,
                "sentiment": sentiment,
                "smart_format": smart_format,
                "summarize": summarize,
                "tag": tag,
                "topics": topics,
                "utt_split": utt_split,
                "utterances": utterances,
                "version": version,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UsageV1Response,
                    parse_obj_as(
                        type_=UsageV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ThinkSettingsV1EndpointParams(typing_extensions.TypedDict):
    """
    Optional for non-Deepgram LLM providers. When present, must include url field and headers object
    """

    url: typing_extensions.NotRequired[str]
    """
    Custom LLM endpoint URL
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Custom headers for the endpoint
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ListenV1ResultsEntitiesItem(UniversalBaseModel):
    label: str = pydantic.Field()
    """
    The type/category of the entity (e.g., NAME, PHONE_NUMBER, EMAIL_ADDRESS, ORGANIZATION, CARDINAL)
    """

    value: str = pydantic.Field()
    """
    The formatted text representation of the entity
    """

    raw_value: str = pydantic.Field()
    """
    The original spoken text of the entity (present when formatting is enabled)
    """

    confidence: float = pydantic.Field()
    """
    The confidence score of the entity detection
    """

    start_word: int = pydantic.Field()
    """
    The index of the first word of the entity in the transcript (inclusive)
    """

    end_word: int = pydantic.Field()
    """
    The index of the last word of the entity in the transcript (exclusive)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .listen_v1response_results_channels_item import ListenV1ResponseResultsChannelsItem

ListenV1ResponseResultsChannels = typing.List[ListenV1ResponseResultsChannelsItem]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.aws_polly_speak_provider_credentials_type import AwsPollySpeakProviderCredentialsType


class AwsPollySpeakProviderCredentialsParams(typing_extensions.TypedDict):
    type: AwsPollySpeakProviderCredentialsType
    region: str
    access_key_id: str
    secret_access_key: str
    session_token: typing_extensions.NotRequired[str]
    """
    Required for STS only
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .agent_v1settings_agent_context_messages_item_content import AgentV1SettingsAgentContextMessagesItemContentParams
from .agent_v1settings_agent_context_messages_item_function_calls import (
    AgentV1SettingsAgentContextMessagesItemFunctionCallsParams,
)

AgentV1SettingsAgentContextMessagesItemParams = typing.Union[
    AgentV1SettingsAgentContextMessagesItemContentParams, AgentV1SettingsAgentContextMessagesItemFunctionCallsParams
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.request_options import RequestOptions
from ......types.get_project_balance_v1response import GetProjectBalanceV1Response
from ......types.list_project_balances_v1response import ListProjectBalancesV1Response
from .raw_client import AsyncRawBalancesClient, RawBalancesClient


class BalancesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawBalancesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawBalancesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawBalancesClient
        """
        return self._raw_client

    def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectBalancesV1Response:
        """
        Generates a list of outstanding balances for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectBalancesV1Response
            A list of outstanding balances

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.billing.balances.list(
            project_id="123456-7890-1234-5678-901234",
        )
        """
        _response = self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    def get(
        self, project_id: str, balance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectBalanceV1Response:
        """
        Retrieves details about the specified balance

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        balance_id : str
            The unique identifier of the balance

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectBalanceV1Response
            A specific balance

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.billing.balances.get(
            project_id="123456-7890-1234-5678-901234",
            balance_id="123456-7890-1234-5678-901234",
        )
        """
        _response = self._raw_client.get(project_id, balance_id, request_options=request_options)
        return _response.data


class AsyncBalancesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawBalancesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawBalancesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawBalancesClient
        """
        return self._raw_client

    async def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectBalancesV1Response:
        """
        Generates a list of outstanding balances for the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectBalancesV1Response
            A list of outstanding balances

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.billing.balances.list(
                project_id="123456-7890-1234-5678-901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    async def get(
        self, project_id: str, balance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectBalanceV1Response:
        """
        Retrieves details about the specified balance

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        balance_id : str
            The unique identifier of the balance

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectBalanceV1Response
            A specific balance

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.billing.balances.get(
                project_id="123456-7890-1234-5678-901234",
                balance_id="123456-7890-1234-5678-901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(project_id, balance_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.agent_v1settings_audio_input_encoding import AgentV1SettingsAudioInputEncoding


class AgentV1SettingsAudioInputParams(typing_extensions.TypedDict):
    """
    Audio input configuration settings. If omitted, defaults to encoding=linear16 and sample_rate=24000. Higher sample rates like 44100 Hz provide better audio quality.
    """

    encoding: AgentV1SettingsAudioInputEncoding
    """
    Audio encoding format
    """

    sample_rate: float
    """
    Sample rate in Hz. Common values are 16000, 24000, 44100, 48000
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1PromptUpdatedParams(typing_extensions.TypedDict):
    type: typing.Literal["PromptUpdated"]
    """
    Message type identifier for prompt update confirmation
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.deepgram_speak_provider_model import DeepgramSpeakProviderModel


class DeepgramParams(typing_extensions.TypedDict):
    type: typing.Literal["deepgram"]
    version: typing_extensions.NotRequired[typing.Literal["v1"]]
    """
    The REST API version for the Deepgram text-to-speech API
    """

    model: DeepgramSpeakProviderModel
    """
    Deepgram TTS model
    """



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class GetProjectKeyV1ResponseItemMemberApiKeyParams(typing_extensions.TypedDict):
    api_key_id: typing_extensions.NotRequired[str]
    comment: typing_extensions.NotRequired[str]
    scopes: typing_extensions.NotRequired[typing.Sequence[str]]
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    expiration_date: typing_extensions.NotRequired[dt.datetime]
    created: typing_extensions.NotRequired[dt.datetime]



# This file was auto-generated by Fern from our API Definition.

import typing

ElevenLabsSpeakProviderModelId = typing.Union[
    typing.Literal["eleven_turbo_v2_5", "eleven_monolingual_v1", "eleven_multilingual_v2"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ListenV1ResponseResultsChannelsItemSearchItemHitsItemParams(typing_extensions.TypedDict):
    confidence: typing_extensions.NotRequired[float]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]
    snippet: typing_extensions.NotRequired[str]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AgentV1SettingsAgentListenProviderV1(UniversalBaseModel):
    type: typing.Literal["deepgram"] = pydantic.Field(default="deepgram")
    """
    Provider type for speech-to-text
    """

    model: typing.Optional[str] = pydantic.Field(default=None)
    """
    Model to use for speech to text using the V1 API (e.g. Nova-3, Nova-2)
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Language code to use for speech-to-text. Can be a BCP-47 language tag (e.g. `en`), or `multi` for code-switching transcription
    """

    keyterms: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Prompt keyterm recognition to improve Keyword Recall Rate
    """

    smart_format: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Applies smart formatting to improve transcript readability
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .listen_v1response_metadata import ListenV1ResponseMetadataParams
from .listen_v1response_results import ListenV1ResponseResultsParams


class ListenV1ResponseParams(typing_extensions.TypedDict):
    """
    The standard transcription response
    """

    metadata: ListenV1ResponseMetadataParams
    results: ListenV1ResponseResultsParams



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .agent_v1settings_agent_context import AgentV1SettingsAgentContext
from .agent_v1settings_agent_listen import AgentV1SettingsAgentListen
from .agent_v1settings_agent_speak import AgentV1SettingsAgentSpeak
from .agent_v1settings_agent_think import AgentV1SettingsAgentThink


class AgentV1SettingsAgent(UniversalBaseModel):
    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deprecated. Use `listen.provider.language` and `speak.provider.language` fields instead.
    """

    context: typing.Optional[AgentV1SettingsAgentContext] = pydantic.Field(default=None)
    """
    Conversation context including the history of messages and function calls
    """

    listen: typing.Optional[AgentV1SettingsAgentListen] = None
    think: typing.Optional[AgentV1SettingsAgentThink] = None
    speak: typing.Optional[AgentV1SettingsAgentSpeak] = None
    greeting: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional message that agent will speak at the start
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItemParams


class UsageFieldsV1ResponseParams(typing_extensions.TypedDict):
    tags: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of tags associated with the project
    """

    models: typing_extensions.NotRequired[typing.Sequence[UsageFieldsV1ResponseModelsItemParams]]
    """
    List of models available for the project.
    """

    processing_methods: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Processing methods supported by the API
    """

    features: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    API features available to the project
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.request_options import RequestOptions
from ......types.usage_fields_v1response import UsageFieldsV1Response
from .raw_client import AsyncRawFieldsClient, RawFieldsClient


class FieldsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFieldsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFieldsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFieldsClient
        """
        return self._raw_client

    def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UsageFieldsV1Response:
        """
        Lists the features, models, tags, languages, and processing method used for requests in the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UsageFieldsV1Response
            A list of fields for a specific project

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.usage.fields.list(
            project_id="123456-7890-1234-5678-901234",
            start="start",
            end="end",
        )
        """
        _response = self._raw_client.list(project_id, start=start, end=end, request_options=request_options)
        return _response.data


class AsyncFieldsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFieldsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFieldsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFieldsClient
        """
        return self._raw_client

    async def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UsageFieldsV1Response:
        """
        Lists the features, models, tags, languages, and processing method used for requests in the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UsageFieldsV1Response
            A list of fields for a specific project

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.usage.fields.list(
                project_id="123456-7890-1234-5678-901234",
                start="start",
                end="end",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(project_id, start=start, end=end, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_project_key_v1response_item_member_api_key import GetProjectKeyV1ResponseItemMemberApiKey


class GetProjectKeyV1ResponseItemMember(UniversalBaseModel):
    member_id: typing.Optional[str] = None
    email: typing.Optional[str] = None
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    api_key: typing.Optional[GetProjectKeyV1ResponseItemMemberApiKey] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .usage_breakdown_v1response_resolution import UsageBreakdownV1ResponseResolutionParams
from .usage_breakdown_v1response_results_item import UsageBreakdownV1ResponseResultsItemParams


class UsageBreakdownV1ResponseParams(typing_extensions.TypedDict):
    start: str
    """
    Start date of the usage period
    """

    end: str
    """
    End date of the usage period
    """

    resolution: UsageBreakdownV1ResponseResolutionParams
    results: typing.Sequence[UsageBreakdownV1ResponseResultsItemParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1results_channel_alternatives_item import ListenV1ResultsChannelAlternativesItemParams


class ListenV1ResultsChannelParams(typing_extensions.TypedDict):
    alternatives: typing.Sequence[ListenV1ResultsChannelAlternativesItemParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ListenV1Metadata(UniversalBaseModel):
    type: typing.Literal["Metadata"] = pydantic.Field(default="Metadata")
    """
    Message type identifier
    """

    transaction_key: str = pydantic.Field()
    """
    The transaction key
    """

    request_id: str = pydantic.Field()
    """
    The request ID
    """

    sha256: str = pydantic.Field()
    """
    The sha256
    """

    created: str = pydantic.Field()
    """
    The created
    """

    duration: float = pydantic.Field()
    """
    The duration
    """

    channels: float = pydantic.Field()
    """
    The channels
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ThinkSettingsV1FunctionsItemEndpoint(UniversalBaseModel):
    """
    The Function endpoint to call. if not passed, function is called client-side
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Endpoint URL
    """

    method: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTTP method
    """

    headers: typing.Optional[typing.Dict[str, str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_sentiments_average import SharedSentimentsAverageParams
from .shared_sentiments_segments_item import SharedSentimentsSegmentsItemParams


class SharedSentimentsParams(typing_extensions.TypedDict):
    """
    Output whenever `sentiment=true` is used
    """

    segments: typing_extensions.NotRequired[typing.Sequence[SharedSentimentsSegmentsItemParams]]
    average: typing_extensions.NotRequired[SharedSentimentsAverageParams]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class DeepgramClientEnvironment:
    PRODUCTION: DeepgramClientEnvironment
    AGENT: DeepgramClientEnvironment

    def __init__(self, *, base: str, production: str, agent: str):
        self.base = base
        self.production = production
        self.agent = agent


DeepgramClientEnvironment.PRODUCTION = DeepgramClientEnvironment(
    base="https://api.deepgram.com", production="wss://api.deepgram.com", agent="wss://agent.deepgram.com"
)
DeepgramClientEnvironment.AGENT = DeepgramClientEnvironment(
    base="https://agent.deepgram.com", production="wss://api.deepgram.com", agent="wss://agent.deepgram.com"
)



# This file was auto-generated by Fern from our API Definition.

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .....types.create_key_v1request_one import CreateKeyV1RequestOne
from .....types.create_key_v1response import CreateKeyV1Response
from .....types.delete_project_key_v1response import DeleteProjectKeyV1Response
from .....types.get_project_key_v1response import GetProjectKeyV1Response
from .....types.list_project_keys_v1response import ListProjectKeysV1Response
from .raw_client import AsyncRawKeysClient, RawKeysClient
from .types.keys_list_request_status import KeysListRequestStatus

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class KeysClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawKeysClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawKeysClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawKeysClient
        """
        return self._raw_client

    def list(
        self,
        project_id: str,
        *,
        status: typing.Optional[KeysListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListProjectKeysV1Response:
        """
        Retrieves all API keys associated with the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        status : typing.Optional[KeysListRequestStatus]
            Only return keys with a specific status

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectKeysV1Response
            A list of API keys

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.keys.list(
            project_id="123456-7890-1234-5678-901234",
            status="active",
        )
        """
        _response = self._raw_client.list(project_id, status=status, request_options=request_options)
        return _response.data

    def create(
        self,
        project_id: str,
        *,
        request: CreateKeyV1RequestOne,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateKeyV1Response:
        """
        Creates a new API key with specified settings for the project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request : CreateKeyV1RequestOne

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateKeyV1Response
            API key created successfully

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.keys.create(
            project_id="project_id",
            request={"key": "value"},
        )
        """
        _response = self._raw_client.create(project_id, request=request, request_options=request_options)
        return _response.data

    def get(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectKeyV1Response:
        """
        Retrieves information about a specified API key

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectKeyV1Response
            A specific API key

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.keys.get(
            project_id="123456-7890-1234-5678-901234",
            key_id="123456789012345678901234",
        )
        """
        _response = self._raw_client.get(project_id, key_id, request_options=request_options)
        return _response.data

    def delete(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectKeyV1Response:
        """
        Deletes an API key for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectKeyV1Response
            API key deleted

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.keys.delete(
            project_id="123456-7890-1234-5678-901234",
            key_id="123456789012345678901234",
        )
        """
        _response = self._raw_client.delete(project_id, key_id, request_options=request_options)
        return _response.data


class AsyncKeysClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawKeysClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawKeysClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawKeysClient
        """
        return self._raw_client

    async def list(
        self,
        project_id: str,
        *,
        status: typing.Optional[KeysListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListProjectKeysV1Response:
        """
        Retrieves all API keys associated with the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        status : typing.Optional[KeysListRequestStatus]
            Only return keys with a specific status

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectKeysV1Response
            A list of API keys

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.keys.list(
                project_id="123456-7890-1234-5678-901234",
                status="active",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(project_id, status=status, request_options=request_options)
        return _response.data

    async def create(
        self,
        project_id: str,
        *,
        request: CreateKeyV1RequestOne,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateKeyV1Response:
        """
        Creates a new API key with specified settings for the project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request : CreateKeyV1RequestOne

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateKeyV1Response
            API key created successfully

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.keys.create(
                project_id="project_id",
                request={"key": "value"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(project_id, request=request, request_options=request_options)
        return _response.data

    async def get(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetProjectKeyV1Response:
        """
        Retrieves information about a specified API key

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectKeyV1Response
            A specific API key

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.keys.get(
                project_id="123456-7890-1234-5678-901234",
                key_id="123456789012345678901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(project_id, key_id, request_options=request_options)
        return _response.data

    async def delete(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectKeyV1Response:
        """
        Deletes an API key for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectKeyV1Response
            API key deleted

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.keys.delete(
                project_id="123456-7890-1234-5678-901234",
                key_id="123456789012345678901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(project_id, key_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item_sentences_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams(typing_extensions.TypedDict):
    sentences: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemSentencesItemParams]
    ]
    speaker: typing_extensions.NotRequired[float]
    num_words: typing_extensions.NotRequired[float]
    start: typing_extensions.NotRequired[float]
    end: typing_extensions.NotRequired[float]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CreateProjectInviteV1ResponseParams(typing_extensions.TypedDict):
    message: typing_extensions.NotRequired[str]
    """
    confirmation message
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .deepgram_speak_provider_model import DeepgramSpeakProviderModel


class Deepgram(UniversalBaseModel):
    type: typing.Literal["deepgram"] = "deepgram"
    version: typing.Optional[typing.Literal["v1"]] = pydantic.Field(default=None)
    """
    The REST API version for the Deepgram text-to-speech API
    """

    model: DeepgramSpeakProviderModel = pydantic.Field()
    """
    Deepgram TTS model
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .listen_v1response_results_channels_item_alternatives_item_paragraphs_paragraphs_item import (
    ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams,
)


class ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParams(typing_extensions.TypedDict):
    transcript: typing_extensions.NotRequired[str]
    paragraphs: typing_extensions.NotRequired[
        typing.Sequence[ListenV1ResponseResultsChannelsItemAlternativesItemParagraphsParagraphsItemParams]
    ]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.listen_v1response_results_utterances_item import ListenV1ResponseResultsUtterancesItem

ListenV1ResponseResultsUtterancesParams = typing.List[ListenV1ResponseResultsUtterancesItem]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .listen_v1results_channel_alternatives_item_words_item import ListenV1ResultsChannelAlternativesItemWordsItem


class ListenV1ResultsChannelAlternativesItem(UniversalBaseModel):
    transcript: str = pydantic.Field()
    """
    The transcript of the transcription
    """

    confidence: float = pydantic.Field()
    """
    The confidence of the transcription
    """

    languages: typing.Optional[typing.List[str]] = None
    words: typing.List[ListenV1ResultsChannelAlternativesItemWordsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentV1KeepAliveParams(typing_extensions.TypedDict):
    """
    Send a control message to the agent
    """

    type: typing.Literal["KeepAlive"]
    """
    Message type identifier
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .shared_topics_results_topics_segments_item_topics_item import (
    SharedTopicsResultsTopicsSegmentsItemTopicsItemParams,
)


class SharedTopicsResultsTopicsSegmentsItemParams(typing_extensions.TypedDict):
    text: typing_extensions.NotRequired[str]
    start_word: typing_extensions.NotRequired[float]
    end_word: typing_extensions.NotRequired[float]
    topics: typing_extensions.NotRequired[typing.Sequence[SharedTopicsResultsTopicsSegmentsItemTopicsItemParams]]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from .....errors.bad_request_error import BadRequestError
from .....types.create_key_v1request_one import CreateKeyV1RequestOne
from .....types.create_key_v1response import CreateKeyV1Response
from .....types.delete_project_key_v1response import DeleteProjectKeyV1Response
from .....types.get_project_key_v1response import GetProjectKeyV1Response
from .....types.list_project_keys_v1response import ListProjectKeysV1Response
from .types.keys_list_request_status import KeysListRequestStatus

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawKeysClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        project_id: str,
        *,
        status: typing.Optional[KeysListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ListProjectKeysV1Response]:
        """
        Retrieves all API keys associated with the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        status : typing.Optional[KeysListRequestStatus]
            Only return keys with a specific status

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListProjectKeysV1Response]
            A list of API keys
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "status": status,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectKeysV1Response,
                    parse_obj_as(
                        type_=ListProjectKeysV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        project_id: str,
        *,
        request: CreateKeyV1RequestOne,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CreateKeyV1Response]:
        """
        Creates a new API key with specified settings for the project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request : CreateKeyV1RequestOne

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CreateKeyV1Response]
            API key created successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateKeyV1Response,
                    parse_obj_as(
                        type_=CreateKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetProjectKeyV1Response]:
        """
        Retrieves information about a specified API key

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetProjectKeyV1Response]
            A specific API key
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys/{jsonable_encoder(key_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectKeyV1Response,
                    parse_obj_as(
                        type_=GetProjectKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DeleteProjectKeyV1Response]:
        """
        Deletes an API key for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DeleteProjectKeyV1Response]
            API key deleted
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys/{jsonable_encoder(key_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteProjectKeyV1Response,
                    parse_obj_as(
                        type_=DeleteProjectKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawKeysClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        project_id: str,
        *,
        status: typing.Optional[KeysListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ListProjectKeysV1Response]:
        """
        Retrieves all API keys associated with the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        status : typing.Optional[KeysListRequestStatus]
            Only return keys with a specific status

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListProjectKeysV1Response]
            A list of API keys
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "status": status,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectKeysV1Response,
                    parse_obj_as(
                        type_=ListProjectKeysV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        project_id: str,
        *,
        request: CreateKeyV1RequestOne,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CreateKeyV1Response]:
        """
        Creates a new API key with specified settings for the project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request : CreateKeyV1RequestOne

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CreateKeyV1Response]
            API key created successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CreateKeyV1Response,
                    parse_obj_as(
                        type_=CreateKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetProjectKeyV1Response]:
        """
        Retrieves information about a specified API key

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetProjectKeyV1Response]
            A specific API key
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys/{jsonable_encoder(key_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectKeyV1Response,
                    parse_obj_as(
                        type_=GetProjectKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, project_id: str, key_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DeleteProjectKeyV1Response]:
        """
        Deletes an API key for a specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        key_id : str
            The unique identifier of the API key

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DeleteProjectKeyV1Response]
            API key deleted
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/keys/{jsonable_encoder(key_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteProjectKeyV1Response,
                    parse_obj_as(
                        type_=DeleteProjectKeyV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.listen_v2turn_info_event import ListenV2TurnInfoEvent
from .listen_v2turn_info_words_item import ListenV2TurnInfoWordsItemParams


class ListenV2TurnInfoParams(typing_extensions.TypedDict):
    """
    Describes the current turn and latest state of the turn
    """

    type: typing.Literal["TurnInfo"]
    request_id: str
    """
    The unique identifier of the request
    """

    sequence_id: float
    """
    Starts at `0` and increments for each message the server sends to the client.  This includes messages of other types, like `Connected` messages.
    """

    event: ListenV2TurnInfoEvent
    """
    The type of event being reported.
    
    - **Update** - Additional audio has been transcribed, but the turn state hasn't changed
    - **StartOfTurn** - The user has begun speaking for the first time in the turn
    - **EagerEndOfTurn** - The system has moderate confidence that the user has finished speaking for the turn. This is an opportunity to begin preparing an agent reply
    - **TurnResumed** - The system detected that speech had ended and therefore sent an **EagerEndOfTurn** event, but speech is actually continuing for this turn
    - **EndOfTurn** - The user has finished speaking for the turn
    """

    turn_index: float
    """
    The index of the current turn
    """

    audio_window_start: float
    """
    Start time in seconds of the audio range that was transcribed
    """

    audio_window_end: float
    """
    End time in seconds of the audio range that was transcribed
    """

    transcript: str
    """
    Text that was said over the course of the current turn
    """

    words: typing.Sequence[ListenV2TurnInfoWordsItemParams]
    """
    The words in the `transcript`
    """

    end_of_turn_confidence: float
    """
    Confidence that no more speech is coming in this turn
    """



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ......core.api_error import ApiError
from ......core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ......core.http_response import AsyncHttpResponse, HttpResponse
from ......core.jsonable_encoder import jsonable_encoder
from ......core.pydantic_utilities import parse_obj_as
from ......core.request_options import RequestOptions
from ......errors.bad_request_error import BadRequestError
from ......types.usage_fields_v1response import UsageFieldsV1Response


class RawFieldsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UsageFieldsV1Response]:
        """
        Lists the features, models, tags, languages, and processing method used for requests in the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UsageFieldsV1Response]
            A list of fields for a specific project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/usage/fields",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UsageFieldsV1Response,
                    parse_obj_as(
                        type_=UsageFieldsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawFieldsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        project_id: str,
        *,
        start: typing.Optional[str] = None,
        end: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UsageFieldsV1Response]:
        """
        Lists the features, models, tags, languages, and processing method used for requests in the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        start : typing.Optional[str]
            Start date of the requested date range. Format accepted is YYYY-MM-DD

        end : typing.Optional[str]
            End date of the requested date range. Format accepted is YYYY-MM-DD

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UsageFieldsV1Response]
            A list of fields for a specific project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/usage/fields",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "start": start,
                "end": end,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UsageFieldsV1Response,
                    parse_obj_as(
                        type_=UsageFieldsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_project_invites_v1response_invites_item import ListProjectInvitesV1ResponseInvitesItemParams


class ListProjectInvitesV1ResponseParams(typing_extensions.TypedDict):
    invites: typing_extensions.NotRequired[typing.Sequence[ListProjectInvitesV1ResponseInvitesItemParams]]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .speak_settings_v1endpoint import SpeakSettingsV1EndpointParams
from .speak_settings_v1provider import SpeakSettingsV1ProviderParams


class SpeakSettingsV1Params(typing_extensions.TypedDict):
    provider: SpeakSettingsV1ProviderParams
    endpoint: typing_extensions.NotRequired[SpeakSettingsV1EndpointParams]
    """
    Optional if provider is Deepgram. Required for non-Deepgram TTS providers.
    When present, must include url field and headers object. Valid schemes are https and wss with wss only supported for Eleven Labs.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class ListModelsV1ResponseSttModelsParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[str]
    canonical_name: typing_extensions.NotRequired[str]
    architecture: typing_extensions.NotRequired[str]
    languages: typing_extensions.NotRequired[typing.Sequence[str]]
    version: typing_extensions.NotRequired[str]
    uuid_: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="uuid")]]
    batch: typing_extensions.NotRequired[bool]
    streaming: typing_extensions.NotRequired[bool]
    formatted_output: typing_extensions.NotRequired[bool]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .list_project_keys_v1response_api_keys_item_api_key import ListProjectKeysV1ResponseApiKeysItemApiKey
from .list_project_keys_v1response_api_keys_item_member import ListProjectKeysV1ResponseApiKeysItemMember


class ListProjectKeysV1ResponseApiKeysItem(UniversalBaseModel):
    member: typing.Optional[ListProjectKeysV1ResponseApiKeysItemMember] = None
    api_key: typing.Optional[ListProjectKeysV1ResponseApiKeysItemApiKey] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .usage_fields_v1response_models_item import UsageFieldsV1ResponseModelsItem


class UsageFieldsV1Response(UniversalBaseModel):
    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tags associated with the project
    """

    models: typing.Optional[typing.List[UsageFieldsV1ResponseModelsItem]] = pydantic.Field(default=None)
    """
    List of models available for the project.
    """

    processing_methods: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Processing methods supported by the API
    """

    features: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    API features available to the project
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .....types.delete_project_member_v1response import DeleteProjectMemberV1Response
from .....types.list_project_members_v1response import ListProjectMembersV1Response
from .raw_client import AsyncRawMembersClient, RawMembersClient

if typing.TYPE_CHECKING:
    from .invites.client import AsyncInvitesClient, InvitesClient
    from .scopes.client import AsyncScopesClient, ScopesClient


class MembersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMembersClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._invites: typing.Optional[InvitesClient] = None
        self._scopes: typing.Optional[ScopesClient] = None

    @property
    def with_raw_response(self) -> RawMembersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMembersClient
        """
        return self._raw_client

    def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectMembersV1Response:
        """
        Retrieves a list of members for a given project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectMembersV1Response
            A list of members for a given project

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.members.list(
            project_id="123456-7890-1234-5678-901234",
        )
        """
        _response = self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    def delete(
        self, project_id: str, member_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectMemberV1Response:
        """
        Removes a member from the project using their unique member ID

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        member_id : str
            The unique identifier of the Member

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectMemberV1Response
            Delete the specific member from the project

        Examples
        --------
        from deepgram import DeepgramClient

        client = DeepgramClient(
            api_key="YOUR_API_KEY",
        )
        client.manage.v1.projects.members.delete(
            project_id="123456-7890-1234-5678-901234",
            member_id="123456789012345678901234",
        )
        """
        _response = self._raw_client.delete(project_id, member_id, request_options=request_options)
        return _response.data

    @property
    def invites(self):
        if self._invites is None:
            from .invites.client import InvitesClient  # noqa: E402

            self._invites = InvitesClient(client_wrapper=self._client_wrapper)
        return self._invites

    @property
    def scopes(self):
        if self._scopes is None:
            from .scopes.client import ScopesClient  # noqa: E402

            self._scopes = ScopesClient(client_wrapper=self._client_wrapper)
        return self._scopes


class AsyncMembersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMembersClient(client_wrapper=client_wrapper)
        self._client_wrapper = client_wrapper
        self._invites: typing.Optional[AsyncInvitesClient] = None
        self._scopes: typing.Optional[AsyncScopesClient] = None

    @property
    def with_raw_response(self) -> AsyncRawMembersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMembersClient
        """
        return self._raw_client

    async def list(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ListProjectMembersV1Response:
        """
        Retrieves a list of members for a given project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListProjectMembersV1Response
            A list of members for a given project

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.members.list(
                project_id="123456-7890-1234-5678-901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(project_id, request_options=request_options)
        return _response.data

    async def delete(
        self, project_id: str, member_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteProjectMemberV1Response:
        """
        Removes a member from the project using their unique member ID

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        member_id : str
            The unique identifier of the Member

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectMemberV1Response
            Delete the specific member from the project

        Examples
        --------
        import asyncio

        from deepgram import AsyncDeepgramClient

        client = AsyncDeepgramClient(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.manage.v1.projects.members.delete(
                project_id="123456-7890-1234-5678-901234",
                member_id="123456789012345678901234",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(project_id, member_id, request_options=request_options)
        return _response.data

    @property
    def invites(self):
        if self._invites is None:
            from .invites.client import AsyncInvitesClient  # noqa: E402

            self._invites = AsyncInvitesClient(client_wrapper=self._client_wrapper)
        return self._invites

    @property
    def scopes(self):
        if self._scopes is None:
            from .scopes.client import AsyncScopesClient  # noqa: E402

            self._scopes = AsyncScopesClient(client_wrapper=self._client_wrapper)
        return self._scopes



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .read_v1response_metadata_metadata import ReadV1ResponseMetadataMetadataParams


class ReadV1ResponseMetadataParams(typing_extensions.TypedDict):
    metadata: typing_extensions.NotRequired[ReadV1ResponseMetadataMetadataParams]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .list_projects_v1response_projects_item import ListProjectsV1ResponseProjectsItemParams


class ListProjectsV1ResponseParams(typing_extensions.TypedDict):
    projects: typing_extensions.NotRequired[typing.Sequence[ListProjectsV1ResponseProjectsItemParams]]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ....core.api_error import ApiError
from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.http_response import AsyncHttpResponse, HttpResponse
from ....core.jsonable_encoder import jsonable_encoder
from ....core.pydantic_utilities import parse_obj_as
from ....core.request_options import RequestOptions
from ....errors.bad_request_error import BadRequestError
from ....types.delete_project_v1response import DeleteProjectV1Response
from ....types.get_project_v1response import GetProjectV1Response
from ....types.leave_project_v1response import LeaveProjectV1Response
from ....types.list_projects_v1response import ListProjectsV1Response
from ....types.update_project_v1response import UpdateProjectV1Response

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawProjectsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[ListProjectsV1Response]:
        """
        Retrieves basic information about the projects associated with the API key

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ListProjectsV1Response]
            A list of projects
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectsV1Response,
                    parse_obj_as(
                        type_=ListProjectsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self,
        project_id: str,
        *,
        limit: typing.Optional[float] = None,
        page: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetProjectV1Response]:
        """
        Retrieves information about the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        limit : typing.Optional[float]
            Number of results to return per page. Default 10. Range [1,1000]

        page : typing.Optional[float]
            Navigate and return the results to retrieve specific portions of information of the response

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetProjectV1Response]
            A project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "limit": limit,
                "page": page,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectV1Response,
                    parse_obj_as(
                        type_=GetProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DeleteProjectV1Response]:
        """
        Deletes the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DeleteProjectV1Response]
            A project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteProjectV1Response,
                    parse_obj_as(
                        type_=DeleteProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        project_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UpdateProjectV1Response]:
        """
        Updates the name or other properties of an existing project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        name : typing.Optional[str]
            The name of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UpdateProjectV1Response]
            A project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="PATCH",
            json={
                "name": name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateProjectV1Response,
                    parse_obj_as(
                        type_=UpdateProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def leave(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[LeaveProjectV1Response]:
        """
        Removes the authenticated account from the specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[LeaveProjectV1Response]
            Successfully removed account from project
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/leave",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    LeaveProjectV1Response,
                    parse_obj_as(
                        type_=LeaveProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawProjectsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ListProjectsV1Response]:
        """
        Retrieves basic information about the projects associated with the API key

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ListProjectsV1Response]
            A list of projects
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ListProjectsV1Response,
                    parse_obj_as(
                        type_=ListProjectsV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self,
        project_id: str,
        *,
        limit: typing.Optional[float] = None,
        page: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetProjectV1Response]:
        """
        Retrieves information about the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        limit : typing.Optional[float]
            Number of results to return per page. Default 10. Range [1,1000]

        page : typing.Optional[float]
            Navigate and return the results to retrieve specific portions of information of the response

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetProjectV1Response]
            A project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            params={
                "limit": limit,
                "page": page,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetProjectV1Response,
                    parse_obj_as(
                        type_=GetProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DeleteProjectV1Response]:
        """
        Deletes the specified project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DeleteProjectV1Response]
            A project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteProjectV1Response,
                    parse_obj_as(
                        type_=DeleteProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        project_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UpdateProjectV1Response]:
        """
        Updates the name or other properties of an existing project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        name : typing.Optional[str]
            The name of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UpdateProjectV1Response]
            A project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="PATCH",
            json={
                "name": name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UpdateProjectV1Response,
                    parse_obj_as(
                        type_=UpdateProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def leave(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[LeaveProjectV1Response]:
        """
        Removes the authenticated account from the specific project

        Parameters
        ----------
        project_id : str
            The unique identifier of the project

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[LeaveProjectV1Response]
            Successfully removed account from project
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/leave",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    LeaveProjectV1Response,
                    parse_obj_as(
                        type_=LeaveProjectV1Response,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        parse_obj_as(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.cartesia_speak_provider_model_id import CartesiaSpeakProviderModelId
from .cartesia_speak_provider_voice import CartesiaSpeakProviderVoiceParams


class CartesiaParams(typing_extensions.TypedDict):
    type: typing.Literal["cartesia"]
    version: typing_extensions.NotRequired[typing.Literal["2025-03-17"]]
    """
    The API version header for the Cartesia text-to-speech API
    """

    model_id: CartesiaSpeakProviderModelId
    """
    Cartesia model ID
    """

    voice: CartesiaSpeakProviderVoiceParams
    language: typing_extensions.NotRequired[str]
    """
    Cartesia language code
    """
